reconstruct_req

Function reconstruct_req 

pub fn reconstruct_req<I: Index, E: Entity>(
    nrows: usize,
    ncols: usize,
    parallelism: Parallelism,
) -> Result<StackReq, SizeOverflow>
Computes the size and alignment of required workspace for reconstructing a matrix out of place, given its partial pivoting LU decomposition.