pub fn reconstruct<I: Index, E: ComplexField>(
dst: MatMut<'_, E>,
lu_factors: MatRef<'_, E>,
row_perm: PermutationRef<'_, I, E>,
parallelism: Parallelism,
stack: PodStack<'_>,
)Expand description
Computes the reconstructed matrix, given its partial pivoting LU decomposition,
and stores the result in dst.
Panics
- Panics if the row permutation doesn’t have the same dimension as the number of rows of the matrix.
- Panics if the destination shape doesn’t match the shape of the matrix.
- Panics if the provided memory in
stackis insufficient (seereconstruct_req).